      subroutine mean_std_cl(a,npts,mean,std,seom,cl70,cl90,cl95,cl99)

! Computes mean, standard deviation, and confidence limits of the array entries

! Also consider (no confidence limits, however):

!      SUBROUTINE avg_std(data,n,avg,std,itype)
      
! Computes mean and standard deviation for an array of data.
! This is based on the Numerical Recipes program avevar.
! Itype specifies the type of mean:
! itype = 1: arithmetic mean, std = standard deviation
! itype = 2: geometric mean, std = factor by which mean is divided
!                                  and multiplied to yield the
!                                  equivalent of minus and plus
!                                  one standard deviation

! Dates: 10/xx/89 - Written
!        11/03/89 - standard error of the mean and confidence
!                   limits added.
!        03/18/97 - Added "dprod" to force double precision
!        02/21/09 - Changed "dbl" to "dble"
!        01/13/12 - I cannot find the function "tin", so I've appended
!                   routines from "mean_cl.for" for computing the 70 and
!                   95% confidence limits
!        06/02 13 - Added cl90 and cl99 to output; changed name

      implicit none
      real mean,std,seom,cl70,cl90,cl95,cl99
      
      real t_70, t_90, t_95, t_99
      
      integer npts, i
      
      
      real a(*)
      double precision sum, sumsq

      sum = 0.0
      sumsq = 0.0

      do 1 i = 1, npts

        sum = sum + a(i)
        sumsq = sumsq + dble(a(i))*dble(a(i))

1     continue

      mean = sum / real(npts)

      std  = dsqrt( (dble(real(npts))*sumsq-sum**2)/
     :         dble(real(npts)*real(npts-1)) )

      seom = std/ sqrt(real(npts))

!      cl70 = seom * tin( 0.850, real(npts-1))
!      cl95 = seom * tin( 0.975, real(npts-1))

      cl70 = t_70(npts-1) * seom
      cl90 = t_90(npts-1) * seom
      cl95 = t_95(npts-1) * seom
      cl99 = t_99(npts-1) * seom

      return
      end

! --------------------- BEGIN t_70 ---------------------------------
      function t_70(n)
! Computes t distribution factor for 15% upper tail for n degrees
! of freedom (use for 70% confidence limits).  Data values from
! Crow etal, Statistics Manual, Table 3, p. 231.

      real t(34)
      integer n_tbl(34)
      data t/
     :   1.963, 1.386, 1.250, 1.190, 1.156, 
     :   1.134, 1.119, 1.108, 1.100, 1.093,
     :   1.088, 1.083, 1.079, 1.076, 1.074, 
     :   1.071, 1.069, 1.067, 1.066, 1.064,
     :   1.063, 1.061, 1.060, 1.059, 1.058,
     :   1.058, 1.057, 1.056, 1.055, 1.055,
     :   1.050, 1.046, 1.041, 1.036/
      data n_tbl/
     :       1,     2,     3,     4,     5,
     :       6,     7,     8,     9,    10,
     :      11,    12,    13,    14,    15,
     :      16,    17,    18,    19,    20,
     :      21,    22,    23,    24,    25,
     :      26,    27,    28,    29,    30,
     :      40,    60,   120, 100000/

      n_loop = 33
      do i = 1, n_loop
        if (n .ge. n_tbl(i) .and. n .lt. n_tbl(i+1)) then
           indx = i
           go to 100
        end if
      end do
      indx = 34
100   continue
      if (indx .eq. 34) then
        t_70 = t(34)
      else
        t_70 = t(indx+1) + (t(indx) - t(indx+1))*
     :       (1.0/float(n)           - 1.0/float(n_tbl(indx+1)))/
     :       (1.0/float(n_tbl(indx)) - 1.0/float(n_tbl(indx+1)))
      end if

      return
      end
! --------------------- END t_70 ---------------------------------

! --------------------- BEGIN t_90 ---------------------------------
      function t_90(n)
! Computes t distribution factor for 5.0% upper tail for n degrees
! of freedom (use for 90% confidence limits).  Data values from
! Crow etal, Statistics Manual, Table 3, p. 231.

      real t(34)
      integer n_tbl(34)
      data t/
     :   6.314, 2.920, 2.353, 2.132, 2.015, 
     :   1.943, 1.895, 1.860, 1.833, 1.812,
     :   1.796, 1.782, 1.771, 1.761, 1.753, 
     :   1.746, 1.740, 1.734, 1.729, 1.725,
     :   1.721, 1.717, 1.714, 1.711, 1.708,
     :   1.706, 1.703, 1.701, 1.699, 1.697,
     :   1.684, 1.671, 1.658, 1.645/
      data n_tbl/
     :       1,     2,     3,     4,     5,
     :       6,     7,     8,     9,    10,
     :      11,    12,    13,    14,    15,
     :      16,    17,    18,    19,    20,
     :      21,    22,    23,    24,    25,
     :      26,    27,    28,    29,    30,
     :      40,    60,   120, 100000/

      n_loop = 33
      do i = 1, n_loop
        if (n .ge. n_tbl(i) .and. n .lt. n_tbl(i+1)) then
           indx = i
           go to 100
        end if
      end do
      indx = 34
100   continue
      if (indx .eq. 34) then
        t_90 = t(34)
      else
        t_90 = t(indx+1) + (t(indx) - t(indx+1))*
     :       (1.0/float(n)           - 1.0/float(n_tbl(indx+1)))/
     :       (1.0/float(n_tbl(indx)) - 1.0/float(n_tbl(indx+1)))
      end if

      return
      end
! --------------------- END t_90 ---------------------------------

! --------------------- BEGIN T_95 ---------------------------------
      function t_95(n)
! Computes t distribution factor for 2.5% upper tail for n degrees
! of freedom (use for 95% confidence limits).  Data values from
! Crow etal, Statistics Manual, Table 3, p. 231.

      real t(34)
      integer n_tbl(34)
      data t/
     :  12.706, 4.303, 3.182, 2.776, 2.571, 
     :   2.447, 2.365, 2.306, 2.262, 2.228,
     :   2.201, 2.179, 2.160, 2.145, 2.131, 
     :   2.120, 2.110, 2.101, 2.093, 2.086,
     :   2.080, 2.074, 2.069, 2.064, 2.060,
     :   2.056, 2.052, 2.048, 2.045, 2.042,
     :   2.021, 2.000, 1.980, 1.960/
      data n_tbl/
     :       1,     2,     3,     4,     5,
     :       6,     7,     8,     9,    10,
     :      11,    12,    13,    14,    15,
     :      16,    17,    18,    19,    20,
     :      21,    22,    23,    24,    25,
     :      26,    27,    28,    29,    30,
     :      40,    60,   120, 100000/

      n_loop = 33
      do i = 1, n_loop
        if (n .ge. n_tbl(i) .and. n .lt. n_tbl(i+1)) then
           indx = i
           go to 100
        end if
      end do
      indx = 34
100   continue
      if (indx .eq. 34) then
        t_95 = 1.960
      else
        t_95 = t(indx+1) + (t(indx) - t(indx+1))*
     :       (1.0/float(n)           - 1.0/float(n_tbl(indx+1)))/
     :       (1.0/float(n_tbl(indx)) - 1.0/float(n_tbl(indx+1)))
      end if

      return
      end
! --------------------- END T_95 ---------------------------------

! --------------------- BEGIN t_99 ---------------------------------
      function t_99(n)
! Computes t distribution factor for 0.5% upper tail for n degrees
! of freedom (use for 99% confidence limits).  Data values from
! Crow etal, Statistics Manual, Table 3, p. 231.

      real t(34)
      integer n_tbl(34)
      data t/
     :  63.657, 9.925, 5.841, 4.604, 4.032, 
     :   3.707, 3.499, 3.355, 3.250, 3.169,
     :   3.106, 3.055, 3.012, 2.977, 2.947, 
     :   2.921, 2.898, 2.878, 2.861, 2.845,
     :   2.831, 2.819, 2.807, 2.797, 2.787,
     :   2.779, 2.771, 2.763, 2.756, 2.750,
     :   2.704, 2.660, 2.617, 2.576/
      data n_tbl/
     :       1,     2,     3,     4,     5,
     :       6,     7,     8,     9,    10,
     :      11,    12,    13,    14,    15,
     :      16,    17,    18,    19,    20,
     :      21,    22,    23,    24,    25,
     :      26,    27,    28,    29,    30,
     :      40,    60,   120, 100000/

      n_loop = 33
      do i = 1, n_loop
        if (n .ge. n_tbl(i) .and. n .lt. n_tbl(i+1)) then
           indx = i
           go to 100
        end if
      end do
      indx = 34
100   continue
      if (indx .eq. 34) then
        t_99 = t(34)
      else
        t_99 = t(indx+1) + (t(indx) - t(indx+1))*
     :       (1.0/float(n)           - 1.0/float(n_tbl(indx+1)))/
     :       (1.0/float(n_tbl(indx)) - 1.0/float(n_tbl(indx+1)))
      end if

      return
      end
! --------------------- END t_99 ---------------------------------

