
! ---------------------------------------------------------------- smcpadf
      subroutine smcpadf(y, npts_in, sps, nlz, ntz, 
     :  replace_discarded_data_with_zeros, 
     :  taper_beginning, taper_end, 
     :  npts_out, izcl, izct, 
     :  remove_mean_before, remove_mean_after, 
     :  zcross_l, use_first, zcross_t, use_last,
     :  comments, ncomments)    

* Here is the padding action taken for some combinations of input parameters:
*
* zcross_l  use_first  pad action (similar for zcross_t, use_last)
*     T         T         pad with 0.0
*     T         F         pad with 0.0
*     F         T         pad with work(1)
*     F         F         pad with 0.0
 
* Dates: 06/04/04 - Replaced tlz, ttz with nlz, ntz.  Also, allow the 
*                   discarded data to be replaced with zeros (thus 
*                   preserving the length of the input time series).
*        03/13/06 - Remove f_smc from smcpadf
*        11/03/06 - If zcross_l or zcross_t = F and use_first or 
*                   use_last = T, pad with values equal to the last points.
*                   Allow this option to deal with cases such as filtering
*                   a displacement time series with a low-frequency drift, 
*                   which will have a step offset if pad with zeros at the
*                   end.  Be careful in in using this option for the first
*                   points, however (in a future version I may eliminate
*                   the option for the beginning, as generally the leading
*                   pad should be zero).  The need for this option arose
*                   when I tried to filter a displacement obtained by 
*                   integrating a zeroth-order corrected acceleration.
*                   The results were different than filtering the 
*                   acceleration before integration.
*        01/24/07 - Store the snipped portion of y_in in a work array.  This
*                   is to be sure that I am not overwriting the input data
*                   when shifting the time series.  Probably the existing
*                   code was OK, but on reading it some years after writing
*                   it, I find it difficult to follow.  It is much better to
*                   make things a bit less efficient, but easier to follow.
*        01/24/07 - Added option to taper end of time series before adding 
*                   trailing zero pad.
*        07/15/07 - Added option to taper beginning of time series before 
*                   adding leading zero pad.
*        07/17/07 - Corrected a subtle error:  the names for the input 
*                   parameters taper_beginning and taper_end were being used
*                   for the variable containing the taper, and thus their
*                   values were being reset to the last taper value.   I now
*                   use "taper" as the variable containing the taper value.
*        03/24/08 - Write leading zpads as a time as well as n points.
*        01/18/10 - Add comments above about padding
!        04/04/10 - Correct error that pad_value_l and pad_value_t could be
!                   undefined in some cases.

  
      logical remove_mean_before, remove_mean_after,
     :  zcross_l, use_first, zcross_t, use_last, 
     :  replace_discarded_data_with_zeros

      real y(*)
      character comments(*)*80

      real work(:)
      allocatable :: work

      parameter (small=1.0e-10)
!      parameter (small=1.0e-05)

      pi = 4.0*atan(1.0)

!* DEBUG
!      write(*,'(a)') ' Inside smcpadf:'
!
!      write(*,'(a)') ' nlz, ntz = '
!      write(*, *)      nlz, ntz
!
!      write(*,'(a)') ' zcross_l, zcross_t = '
!      write(*, *)      zcross_l, zcross_t
!
!      write(*,'(a)') ' use_first, use_last = '
!      write(*, *)      use_first, use_last
!
!      write(*,'(a,1x,l1)') 
!     :      ' remove_mean_before = ', remove_mean_before
!
!      write(*,'(a,1x,l1)') 
!     :      ' remove_mean_after = ', remove_mean_after
!
      if (remove_mean_before) then        
        n_start = 1
        n_stop = npts_in
        icorr_cumavg_before = 0
        call Get_Avg(y, n_start, n_stop, npts_in, 
     :                   sps, icorr_cumavg_before, avg_before)
        do i = n_start, n_stop
          y(i) = y(i) - avg_before
        end do
        n_start_before = n_start
        n_stop_before = n_stop
      end if

* Get peak motion:
      
      call mnmaxidx(y, 1, npts_in, 1,
     :             ymin, ymax, indx_min, indx_max) 
      peak_mtn = ymax
      if (abs(ymin) .gt. abs(ymax)) peak_mtn = ymin

* Define fraction small of peak:
      smidge = small * abs(peak_mtn)


      if (zcross_l) then ! Find first zero crossing
        izcl = -1
        if (abs(y(1)) .lt. smidge) then
          izcl = 1
        else
          do i = 2, npts_in
            if (y(i)*y(1) .lt. 0.0) then   ! a zero crossing has been found
* Now determine if the point just before the zero crossing is smaller in 
* amplitude than the point after.  If so, let it be the first point unless 
* the first value is smaller than this value, in which case y(1) is the 
* first value.
              if (abs(y(i)) .lt. abs(y(i-1))) then
                izcl = i
              else
                izcl = i - 1
                if (use_first) then
                  if (abs(y(i-1)) .gt. abs(y(1))) then
                    izcl = 1
                  end if
                end if
              end if
              go to 2345
            end if
          end do
2345      continue
        end if
      else
        izcl = 1
      end if
      if (zcross_t) then ! Find last zero crossing
        izct = -1
        if (abs(y(npts_in)) .lt. smidge) then
          izct = npts_in
        else
          do i = npts_in -1, 1, -1
            if (y(i)*y(npts_in) .lt. 0.0) then ! a zero crossing has been found
* Now determine if the point just after the zero crossing is smaller in 
* amplitude than the point before.  If so, let it be the last point unless 
* the last value is smaller than this value, in which case y(npts_in) is the 
* last value.
              if (abs(y(i)) .lt. abs(y(i+1))) then
                izct = i
              else
                izct = i+1
                if (use_last) then
                  if (abs(y(i+1)) .gt. abs(y(npts_in))) then
                    izct = npts_in
                  end if
                end if
              end if
              go to 5432
            end if
          end do
5432      continue
        end if
      else
        izct = npts_in
      end if

!      write(*,'(a)') ' izcl, izct = '
!      write(*,*)       izcl, izct

* izcl, izct = index in input smc file of zero crossings

* April's code is more compact, but I think mine is easier to read        
            
      if (replace_discarded_data_with_zeros) then
        nlznew = nlz + izcl - 1
        ntznew = ntz + npts_in - izct
      else
        nlznew = nlz
        ntznew = ntz
      end if

* Allocate a work array and save the snipped portion in this array

      npts_snip = izct - izcl + 1  ! number of original points between zeros
      allocate (work(npts_snip)) 
      do i = 1, npts_snip
        work(i) = y(i+izcl-1)
      end do
      
* Compute new npts_out:

      npts_out = npts_snip + nlznew + ntznew

* Indices of original data

        n_start = nlznew + 1
        n_stop = npts_snip + nlznew

* Compute and remove mean if specified:

      if (remove_mean_after) then        
        n_start4avg = 1
        n_stop4avg = npts_snip 
        icorr_cumavg_after = 1

        call Get_Avg(work, n_start4avg, n_stop4avg, npts_snip, 
     :                   sps, icorr_cumavg_after, avg_after)
        do i = 1, npts_snip
          work(i) = work(i) - avg_after
        end do
        n_start_after = n_start
        n_stop_after = n_stop
      end if

* Taper beginning, if desired:

      ntaper_beginning = taper_beginning*sps
      
      if (ntaper_beginning .gt. 0) then
      
!* DEBUG
!        print *,' ntaper_beginning = ', ntaper_beginning
!* DEBUG
      
        do i = 1, ntaper_beginning + 1
        
           ishift = i - (1 - ntaper_beginning)
           arg = pi*float(ishift)/float(ntaper_beginning)
           taper = 0.5*(1.0+cos(arg))
           
           work(i) = taper * work(i)
           
        end do
        
      end if



* Taper end, if desired:

      ntaper_end = taper_end*sps
      
      if (ntaper_end .gt. 0) then
      
!* DEBUG
!        print *,' ntaper_end = ', ntaper_end  
!* DEBUG
      
        do i = npts_snip - ntaper_end, npts_snip
        
           ishift = i - (npts_snip - ntaper_end)
           arg = pi*float(ishift)/float(ntaper_end)
           taper = 0.5*(1.0+cos(arg))
           
           work(i) = taper * work(i)
           
        end do
        
      end if



* Store work in shifted location in y

      do i = 1, npts_snip
        y(i + nlznew) = work(i)
      end do
      
* And pad with leading zeros:

      pad_value_l = 0.0
      if ( nlznew .gt. 0) then
        if ((.not. zcross_l) .and. use_first) then
          pad_value_l = work(1)
        else
          pad_value_l = 0.0
        end if
        
        do i = 1, nlznew
          y(i) = pad_value_l
        end do
      end if

* And pad with trailing zeros:

      pad_value_t = 0.0
      if ( ntznew .gt. 0) then
        if ((.not. zcross_t) .and. use_last) then
          pad_value_t = work(npts_snip)
        else
          pad_value_t = 0.0
        end if

        do i = 1, ntznew
          y(npts_snip + nlznew + i) = pad_value_t
        end do
      end if

      deallocate(work)

* Store  comments:
      ncomments = ncomments + 1
      write(comments(ncomments),'(a)') 
     :     '| Added pads:'
      if (remove_mean_before) then        
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| Using icorr_cumavg = ', icorr_cumavg_before, 
     :   ', determined and removed the mean', avg_before
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i5,1x,a,1x,i5,a)') 
     :   '| between indices ', n_start_before, ' and ',
     :        n_stop_before, ' before padding with pad_value'
      else
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| No mean removed before adding pad' 
      end if
      if (remove_mean_after) then        
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| Using icorr_cumavg = ', icorr_cumavg_after, 
     :   ', determined and removed the mean', avg_after
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i5,1x,a,1x,i5,a)') 
     :   '| between indices ', n_start_after, ' and ',
     :        n_stop_after, ' after padding with pad_value'
      else
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| No mean removed after adding pads' 
      end if
      
      if (ntaper_beginning .gt. 0) then
!* DEBUG
!        print *,' In write comments:'
!        print *,' ntaper_beginning = ', ntaper_beginning  
!* DEBUG
      
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i7,a)')
     :     '| Taper beginning ', ntaper_beginning,
     :     ' points before adding leading pad'
      end if
          
      if (ntaper_end .gt. 0) then
!* DEBUG
!        print *,' In write comments:'
!        print *,' ntaper_end = ', ntaper_end 
!* DEBUG
      
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i7,a)')
     :     '| Taper last ', ntaper_end,
     :     ' points before adding trailing pad'
      end if
          
      ncomments = ncomments + 1
      if (replace_discarded_data_with_zeros) then
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program replaced ', izcl - 1, 
     :      ' points from start of record with pad value'
      else
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program discarded ', izcl - 1, 
     :      ' points from the start of the record'
      end if
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7,a,
     :                            f7.3,a)') 
     :     '|   and added ', nlz, ' leading values ( ', 
     :                     float(nlz)/sps, ' s), using'
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,l1,a,1x,l1)') 
     :     '|   zcross_l = ', zcross_l,
     :        ' and use_first = ', use_first
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,1p, e10.3)') 
     :     '|   and pad_value = ', pad_value_l
      ncomments = ncomments + 1
      if (replace_discarded_data_with_zeros) then
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program replaced ', npts_in - izct, 
     :      ' points from end of record with pad_value'
      else
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program discarded ', npts_in - izct, 
     :      ' points from the end of the record'
      end if
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7,a)') 
     :     '|   and added ', ntz, ' trailing values, using'
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,l1,a,1x,l1)') 
     :     '|   zcross_t = ', zcross_t,
     :        ' and use_last = ', use_last
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,1p, e10.3)') 
     :     '|   and pad_value = ', pad_value_t
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7)') 
     :     '| The total number of points in the input time'//
     :        ' series = ', npts_in
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7)') 
     :     '| The total number of points in the '//
     :       'pad-stripped series = ', npts_out - nlz - ntz

      return
      end
! ---------------------------------------------------------------- smcpadf


