! -------------------------- BEGIN SMTHS --------------------------
      subroutine SMTHS (Z,IPW2,df_fas,df_smooth,IMODE)

! SMTHS - smooth amplitude spectrum Z with a triangle window.
!         Assume Z(1) corresponds to DC; smooth up to Nyquist.
!         If IMODE = 1, smooth amplitudes.
!         If IMODE = 2, smooth log amplitudes.

! Amount of smoothing is determined by the ratio df_smooth/df_fas.
! The smoothing triangle base has an odd integer number of points 
! given by (2*ihwid+1), where ihwid = nint(df_smooth/df_fas).  
! df_smooth = 0.0 => no smoothing.  df_smooth is half the width of the 
! triangular smoothing window.
! 
! Smooth index range 2...IPW2/2;
! shift results to IPW2/2+2...IPW2 and shift back to 2...IPW2/2 at the end.
! the two outside points get zero weight, so IHWID<=1 implies no smooth.
! Notice that beginning and end of spectrum are only partially smoothed.
! Written by Chuck Mueller, USGS.

! Dates:  xx/xx/xx - Written by Chuck Mueller
!          2/ 6/90 - IHWID set to '1' if it is less than unity.
!                    This was done because in PROCESS IHWID is 
!                    determined by IHWID = nint(DF_SMOOTH/DF_FFT),
!                    and this evaluates to 0 if DF_SMOOTH is very
!                    small (as is the case if no smoothing is desired).
!         12/13/00 - df_smooth as input
!        04/24/18 - Replace comment characters * and c with !

      real Z(IPW2)

      ihwid = nint(df_smooth/df_fas)

      if (ihwid .le. 1) return

      ISHIFT = IPW2/2
10    do 13 I=1,IHWID
         FACT = 1./I
         WSUM = 0.
         ZSUM = 0.
         if (IMODE.eq.1) then
           do 11 J=1,2*I-1
              W = (I-IABS(I-J))*FACT
              WSUM = WSUM+W
11            ZSUM = ZSUM+W*Z(J+1)
           Z(I+1+ISHIFT) = ZSUM/WSUM
         elseif (IMODE.eq.2) then
           do 12 J=1,2*I-1
              W = (I-IABS(I-J))*FACT
              WSUM = WSUM+W
12            ZSUM = ZSUM+W*ALOG10(Z(J+1))
           Z(I+1+ISHIFT) = 10.**(ZSUM/WSUM)
         endif
13       continue
20    FACT = 1./IHWID
      do 23 I=IHWID+1,IPW2/2-(IHWID+1)
         WSUM = 0.
         ZSUM = 0.
         if (IMODE.eq.1) then
           do 21 J=I-IHWID+1,I+IHWID-1
              W = (IHWID-IABS(I-J))*FACT
              WSUM = WSUM+W
21            ZSUM = ZSUM+W*Z(J+1)
           Z(I+1+ISHIFT) = ZSUM/WSUM
         elseif (IMODE.eq.2) then
           do 22 J=I-IHWID+1,I+IHWID-1
              W = (IHWID-IABS(I-J))*FACT
              WSUM = WSUM+W
22            ZSUM = ZSUM+W*ALOG10(Z(J+1))
           Z(I+1+ISHIFT) = 10.**(ZSUM/WSUM)
         endif
23       continue
30    do 33 I=IPW2/2-IHWID,IPW2/2-1
         FACT = 1./(IPW2/2-I)
         WSUM = 0.
         ZSUM = 0.
         if (IMODE.eq.1) then
           do 31 J=IPW2/2-2*(IPW2/2-I)+1,IPW2/2-1
              W = (IHWID-IABS(I-J))*FACT
              WSUM = WSUM+W
31            ZSUM = ZSUM+W*Z(J+1)
           Z(I+1+ISHIFT) = ZSUM/WSUM
         elseif (IMODE.eq.2) then
           do 32 J=IPW2/2-2*(IPW2/2-I)+1,IPW2/2-1
              W = (IHWID-IABS(I-J))*FACT
              WSUM = WSUM+W
32            ZSUM = ZSUM+W*ALOG10(Z(J+1))
           Z(I+1+ISHIFT) = 10.**(ZSUM/WSUM)
         endif
33       continue
40    do 41 I=2,IPW2/2
41       Z(I) = Z(I+ISHIFT)
      return

      end
! -------------------------- END SMTHS --------------------------
