* ---------------------------------------------------------------- smcpadf
      subroutine smcpadf(y, npts_in, sps, nlz, ntz, 
     :  replace_discarded_data_with_zeros, 
     :  detrend_acceleration,
     :  npts_out, izcl, izct, 
     :  remove_mean_before, remove_mean_after, 
     :  zcross_l, use_first, zcross_t, use_last,
     :  comments, ncomments)    

* Dates: 06/04/04 - Replaced tlz, ttz with nlz, ntz.  Also, allow the discarded
*                   data to be replaced with zeros (thus preserving the length
*                   of the input time series).
*        07/09/04 - Include an option for the removal of a straight line fit
*                   to the first and last points.  If do this, reset the
*                   parameters controlling going to the first zero crossing
*                   and removing means to "N"

      logical remove_mean_before, remove_mean_after,
     :  zcross_l, use_first, zcross_t, use_last, 
     :  replace_discarded_data_with_zeros,
     :  detrend_acceleration

      real y(*)
      character comments(*)*80

      parameter (small=1.0e-10)
!      parameter (small=1.0e-05)


      if (detrend_acceleration) then  ! remove line fit to first and last 
                                      ! points; in future, may want to  
                                      ! generalize to allow detrending of 
                                      ! velocity
        slope = (y(npts_in) - y(1))/float(npts_in-1)
        a_1 = y(1)
* DEBUG
        write(*,'(a)') 
     :      ' Before do i, y(1), y(npts_in), a_1, slope = '
        write(*, *)      y(1), y(npts_in), a_1, slope
* DEBUG
        do i = 1, npts_in
          y(i) = y(i) - (a_1 + slope*float(i-1))
        end do
* DEBUG
        write(*,'(a)') 
     :      ' After do i, y(1), y(npts_in), a_1, slope = '
        write(*, *)      y(1), y(npts_in), a_1, slope
* DEBUG

        remove_mean_before = .false.
        remove_mean_after = .false.
        zcross_l = .false.
        zcross_t = .false.
        replace_discarded_data_with_zeros = .true. ! do not have to reset this

      end if

      write(*,'(a,1x,l1)') 
     :      ' remove_mean_before = ', remove_mean_before

      write(*,'(a,1x,l1)') 
     :      ' remove_mean_after = ', remove_mean_after

      if (remove_mean_before) then        
        n_start = 1
        n_stop = npts_in
        icorr_cumavg_before = 0
        call Get_Avg(y, n_start, n_stop, npts_in, 
     :                   sps, icorr_cumavg_before, avg_before)
        do i = n_start, n_stop
          y(i) = y(i) - avg_before
        end do
        n_start_before = n_start
        n_stop_before = n_stop
      end if

* Get peak motion:
      
      call mnmaxidx(y, 1, npts_in, 1,
     :             ymin, ymax, indx_min, indx_max) 
      peak_mtn = ymax
      if (abs(ymin) .gt. abs(ymax)) peak_mtn = ymin

* Define fraction small of peak:
      smidge = small * abs(peak_mtn)


      if (zcross_l) then ! Find first zero crossing
        izcl = -1
        if (abs(y(1)) .lt. smidge) then
          izcl = 1
        else
          do i = 2, npts_in
            if (y(i)*y(1) .lt. 0.0) then   ! a zero crossing has been found
* Now determine if the point just before the zero crossing is smaller in 
* amplitude than the point after.  If so, let it be the first point unless 
* the first value is smaller than this value, in which case y(1) is the 
* first value.
              if (abs(y(i)) .lt. abs(y(i-1))) then
                izcl = i
              else
                izcl = i - 1
                if (use_first) then
                  if (abs(y(i-1)) .gt. abs(y(1))) then
                    izcl = 1
                  end if
                end if
              end if
              go to 2345
            end if
          end do
2345      continue
        end if
      else
        izcl = 1
      end if
      if (zcross_t) then ! Find last zero crossing
        izct = -1
        if (abs(y(npts_in)) .lt. smidge) then
          izct = npts_in
        else
          do i = npts_in -1, 1, -1
            if (y(i)*y(npts_in) .lt. 0.0) then ! a zero crossing has been found
* Now determine if the point just after the zero crossing is smaller in 
* amplitude than the point before.  If so, let it be the last point unless 
* the last value is smaller than this value, in which case y(npts_in) is the 
* last value.
              if (abs(y(i)) .lt. abs(y(i+1))) then
                izct = i
              else
                izct = i+1
                if (use_last) then
                  if (abs(y(i+1)) .gt. abs(y(npts_in))) then
                    izct = npts_in
                  end if
                end if
              end if
              go to 5432
            end if
          end do
5432      continue
        end if
      else
        izct = npts_in
      end if

* izcl, izct = index in input smc file of zero crossings

* April's code is more compact, but I think mine is easier to read        
            
      if (replace_discarded_data_with_zeros) then
        nlznew = nlz + izcl - 1
        ntznew = ntz + npts_in - izct
      else
        nlznew = nlz
        ntznew = ntz
      end if

* Shift the time series to make room for the leading zeros:

      npts_snip = izct - izcl + 1  ! number of original points between zeros
      do i = npts_snip + nlznew, nlznew + 1, -1
        y(i) = y(i-nlznew-1+izcl)
      end do

* Compute new npts_out:

      npts_out = npts_snip + nlznew + ntznew

* Compute and remove mean if specified:

      if (remove_mean_after) then        
        n_start = nlznew + 1
        n_stop = npts_snip + nlznew
        icorr_cumavg_after = 1

        call Get_Avg(y, n_start, n_stop, npts_out, 
     :                   sps, icorr_cumavg_after, avg_after)
        do i = n_start, n_stop
          y(i) = y(i) - avg_after
        end do
        n_start_after = n_start
        n_stop_after = n_stop
      end if

* And pad with leading zeros:

      if ( nlznew .gt. 0) then
        do i = 1, nlznew
          y(i) = 0.0
        end do
      end if

* And pad with trailing zeros:

      if ( ntznew .gt. 0) then
        do i = 1, ntznew
          y(npts_snip + nlznew + i) = 0.0
        end do
      end if

* DEBUG
        write(*,'(a)') 
     :      ' Before store comments, '//
     :      ' nlznew, npts_snip = '
        write(*, *)   nlznew, npts_snip
        write(*,'(a)') 
     :      ' Before store comments, '//
     :      'y(nlznew+1), y(nlznew+npts_snip), a_1, slope = '
        write(*, *)      y(nlznew+1), y(nlznew+npts_snip), a_1, slope
* DEBUG
* Store  comments:
      ncomments = ncomments + 1
      write(comments(ncomments),'(a)') 
     :    '| Added zero pads:'
      if (detrend_acceleration) then        
        ncomments = ncomments + 1
        write(comments(ncomments),'(a)') 
     :    '| Detrended acceleration by removing line fit to '//
     :         'first and last points;'
      end if
      if (remove_mean_before) then        
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| Using icorr_cumavg = ', icorr_cumavg_before, 
     :   ', determined and removed the mean', avg_before
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i5,1x,a,1x,i5,a)') 
     :   '| between indices ', n_start_before, ' and ',
     :        n_stop_before, ' before padding with zeros'
      else
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| No mean removed before adding zeros' 
      end if
      if (remove_mean_after) then        
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| Using icorr_cumavg = ', icorr_cumavg_after, 
     :   ', determined and removed the mean', avg_after
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i5,1x,a,1x,i5,a)') 
     :   '| between indices ', n_start_after, ' and ',
     :        n_stop_after, ' after padding with zeros'
      else
        ncomments = ncomments + 1
        write(comments(ncomments),'(a,1x,i1,a,1x,1p,e11.4)') 
     :   '| No mean removed after adding zeros' 
      end if
      ncomments = ncomments + 1
      if (replace_discarded_data_with_zeros) then
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program replaced ', izcl - 1, 
     :      ' points from the start of the record with zeros'
      else
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program discarded ', izcl - 1, 
     :      ' points from the start of the record'
      end if
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7,a)') 
     :     '|   and added ', nlz, ' leading zeros, using'
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,l1,a,1x,l1)') 
     :     '|   zcross_l = ', zcross_l,
     :        ' and use_first = ', use_first
      ncomments = ncomments + 1
      if (replace_discarded_data_with_zeros) then
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program replaced ', npts_in - izct, 
     :      ' points from the end of the record with zeros'
      else
        write(comments(ncomments),'(a,1x,i7,a)') 
     :     '| The program discarded ', npts_in - izct, 
     :      ' points from the end of the record'
      end if
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7,a)') 
     :     '|   and added ', ntz, ' trailing zeros, using'
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,l1,a,1x,l1)') 
     :     '|   zcross_t = ', zcross_t,
     :        ' and use_last = ', use_last
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7)') 
     :     '| The total number of points in the input time'//
     :        ' series = ', npts_in
      ncomments = ncomments + 1
      write(comments(ncomments),'(a,1x,i7)') 
     :     '| The total number of points in the '//
     :       'pad-stripped series = ', npts_out - nlz - ntz

      return
      end
* ---------------------------------------------------------------- smcpadf

      include '\forprogs\get_avg.for'
