! ------------------------------------------------------  begin construct_filename_extension
      subroutine construct_filename_extension
     :      (tskip, tlength, option, 
     :       flc, nslope_lc, icaus_lc,
     :       fhc, nslope_hc, icaus_hc, icaus_bn,
     :       filter_type, nc_filter_type,
     :       taper_beginning, taper_end, 
     :       fn_ext_c, nc_fn_ext_c)
     
! Construct a filename extension based on the blpadflt parameter
! "option" (10=no baseline) and the blpadflt filtering  
! parameters.  At this time I do not include baseline correction or
! tapering details, as these are less commonly used than the filtering

! Dates: 12/08/09 - Add taper info to filename
!        01/25/10 - Correct error in construct_filename_extension.for when auto naming the 
!                   output file if only remove mean (no filtering).
!        03/11/10 - Correct error of not calling trim_c for fn_ext_c
!        03/20/10 - Allow for a notch filter.
!        12/04/10 - Add tskip, tlength to name
!        05/16/14 - Modernize boolean statements
!                 - Introduce option==11 to mean no baseline, and no mean removed.
!                   I needed this in order to make the filename of the unfiltered velocity
!                   time series in the filt_plot_lc output indicate correctly whether
!                   or not a mean had been removed.
!        07/11/17 - Add more filter possibilities
!        07/13/17 - Determine filter type in calling program
!        01/09/20 - Change portion of automatic filename for baseline correction from 
!                   "blc" to "v0_blc" for option 3.
     
      character fn_ext_c*(*), d_c*6, freql_c*6, freqh_c*6, ns_c*2
      integer option
      character filter_type*(*)
      
      fn_ext_c = ' '
      fn_ext_c = '.tskp'

      call trim_c(fn_ext_c, nc_fn_ext_c)
      if (tskip < 10.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+3),
     :             '(f3.1)') tskip
      else if (tskip < 100.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+4),
     :             '(f4.1)') tskip
      else if (tskip < 1000.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+5),
     :             '(f5.1)') tskip
      else if (tskip < 10000.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+6),
     :             '(f6.1)') tskip
      else 
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+7),
     :             '(f7.1)') tskip
      end if
      call trim_c(fn_ext_c, nc_fn_ext_c)
      
      fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.tread'
      call trim_c(fn_ext_c, nc_fn_ext_c)
      if (tlength <  0.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+4),
     :             '(f4.1)') tlength
      else if (tlength < 10.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+3),
     :             '(f3.1)') tlength
      else if (tlength < 100.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+4),
     :             '(f4.1)') tlength
      else if (tlength < 1000.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+5),
     :             '(f5.1)') tlength
      else if (tlength < 10000.0) then
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+6),
     :             '(f6.1)') tlength
      else 
        write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+7),
     :             '(f7.1)') tlength
      end if
      call trim_c(fn_ext_c, nc_fn_ext_c)
     
      if (icaus_lc == 1 .and. icaus_hc == 1) then
        icaus = 1
      else
        icaus = 0
        end if


      
      if (filter_type(1:nc_filter_type) == 'NF') then  ! no filter
        if (option == 10 .or. option == 11) then ! no baseline correction
          if (option == 11) then
            fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.xrm'
          else
            fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.rm'
          end if
        else  ! baseline correction
          if (option == 3) then          
            fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.v0_blc'
          else
            fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.blc'
          end if
        end if
        call trim_c(fn_ext_c, nc_fn_ext_c)

      else ! filtering
      
        if (filter_type(1:nc_filter_type) /= 'NF') then  ! A filter has been applied

          if (filter_type(1:nc_filter_type) == 'LC') then ! locut only
            ns_c = ' '
            write(ns_c(1:2),'(i2.2)') nslope_lc
            call freq2char(flc, freql_c)
            if (icaus_lc == 0) then
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.alc'//freql_c(1:6)//'ns'//ns_c(1:2)
            else
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.clc'//freql_c(1:6)//'ns'//ns_c(1:2)
            end if
          else if (filter_type(1:nc_filter_type) == 'HC') then ! hicut only
            ns_c = ' '
            write(ns_c(1:2),'(i2.2)') nslope_hc
            call freq2char(fhc, freqh_c)
            if (icaus_hc == 0) then
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.ahc'//freqh_c(1:6)//'ns'//ns_c(1:2)
            else
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.chc'//freqh_c(1:6)//'ns'//ns_c(1:2)
            end if
          else if (filter_type(1:nc_filter_type) == 'NOTCH') then ! notch
            d = real(nslope_lc)*10.0**(-real(nslope_hc))
            call freq2char(flc, freql_c)
            call freq2char(d, d_c)
            if (icaus_bn == 1) then  !causal
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :       '.cnotch'//freql_c(1:6)//'d'//d_c(1:6)
            else
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :       '.anotch'//freql_c(1:6)//'d'//d_c(1:6)
            end if
          else if (filter_type(1:nc_filter_type) == 'BAND') then ! bandpass          
            nslope_bp = max0(nslope_lc, nslope_hc)
            ns_c = ' '
            write(ns_c(1:2),'(i2.2)') nslope_bp
            call freq2char(flc, freql_c)
            call freq2char(fhc, freqh_c)
            if (icaus_bn == 0) then
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :       '.abp'//freql_c(1:6)//'-'//freqh_c(1:6)//'ns'//ns_c(1:2)
            else
                fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :       '.cbp'//freql_c(1:6)//'-'//freqh_c(1:6)//'ns'//ns_c(1:2)
            end if
          else if (filter_type(1:nc_filter_type) == 'LCHC') then ! locut followed by hicut
            ns_c = ' '
            write(ns_c(1:2),'(i2.2)') nslope_lc
            call freq2char(flc, freql_c)
            if (icaus_lc == 0) then
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.alc'//freql_c(1:6)//'ns'//ns_c(1:2)
            else
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.clc'//freql_c(1:6)//'ns'//ns_c(1:2)
            end if
            call trim_c(fn_ext_c, nc_fn_ext_c)
            ns_c = ' '
            write(ns_c(1:2),'(i2.2)') nslope_hc
            call freq2char(fhc, freqh_c)
            if (icaus_hc == 0) then
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.ahc'//freqh_c(1:6)//'ns'//ns_c(1:2)
            else
              fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//
     :         '.chc'//freqh_c(1:6)//'ns'//ns_c(1:2)
            end if
          else
            write(*,'(a)') 
     :          ' In construct_filename_extension, '//
     :          'unknown filter type; quitting!!! '
            stop
          end if
        end if

        call trim_c(fn_ext_c, nc_fn_ext_c)

! Add taper info if an acausal filter:
 
        if (icaus_bn == 0 .or. icaus_lc == 0 .or. icaus_hc == 0) then 
      
          fn_ext_c = fn_ext_c(1:nc_fn_ext_c)//'.taper_'
          call trim_c(fn_ext_c, nc_fn_ext_c)
        
          if (taper_beginning >= 10.0) then
            write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+4),
     :             '(f4.1)') taper_beginning
          else
            fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+1) = '_'
            write(fn_ext_c(nc_fn_ext_c+2:nc_fn_ext_c+4),
     :             '(f3.1)') taper_beginning
          end if
        
          fn_ext_c(nc_fn_ext_c+5:nc_fn_ext_c+5) = '_'
          call trim_c(fn_ext_c, nc_fn_ext_c)
          if (taper_end >= 10.0) then
            write(fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+4),
     :             '(f4.1)') taper_end
          else
            fn_ext_c(nc_fn_ext_c+1:nc_fn_ext_c+1) = '_'
            write(fn_ext_c(nc_fn_ext_c+2:nc_fn_ext_c+4),
     :             '(f3.1)') taper_end
          end if
 
          call trim_c(fn_ext_c, nc_fn_ext_c)
        end if

      end if 
      
      call trim_c(fn_ext_c, nc_fn_ext_c)
      
      return
      end
! ------------------------------------------------------  end construct_filename_extension

      
! ------------------------------------------------------  begin freq2char
      subroutine freq2char(f, freq_c)
        character freq_c*6
        real f
        freq_c = '000000'
        if (f.lt.10.0) then
          write(freq_c(2:6),'(f5.3)') f
        else  
          write(freq_c(1:6),'(f6.3)') f
        end if
        
      return
      end
! ------------------------------------------------------  end freq2char      