! ----------------------------------------------------------------- DIST3DMF
      subroutine dist3dmf(cartesian_coordinates, N_sta, E_sta, elev_sta,
     : N_ref, E_ref, elev_ref, h_ref, strike_f, dip_f,
     : w1, w2, s1, s2, nflts, h_min_c, 
     : icase_jb, d_jb, az_jb, rx_nga, ry0_nga,
     : d_cd2f, az_cd2f, 
     : d_c, az_c, d_jb_segs, d_cd2f_segs, d_c_segs,
     : az_jb_segs, icase_jb_segs, rx_nga_segs, ry0_nga_segs)

! Calls dist_3df for each fault, and returns the minimum distances

! Dates: 09/17/00 - Written by D. Boore
!        12/03/00 - Account for elevation (in meters) of fault and station
!        09/16/10 - Add icase_jb to output; az_jb is the azimuth for the last segment
!        09/27/10 - Return distances and azimuth for each segment
!        01/10/17 - Add rx_nga for the last segment to the output. This is
!                   confusing nomenclature, as this is computed 
!                   as rz_jb + w1*cos(dip).  I cannot recall why we defined
!                   the fault coordinates as x and z.
!        08/11/17 - Set default d_rb, etc to 10000. 
!        12/17/19 - Add ry0_nga_segs to the output
!        12/20/19 - Allow reference and station coordinates to be in Cartesian 
!                   coordinates or geographic coordinates (lat/long)
!                 - Add rx_nga and ry0_nga to output, computed as the minimum
!                   values (positive in the case of ry0_nga) for all the fault
!                   segments.  This is probably not very meaningful for multi
!                   fault segments, but it will result in the values being written
!                   into the first set of results rather than only in the results for
!                   each fault segment.

      implicit none
      
      real az_c, d_c, az_cd2f, d_cd2f, ry0_nga, rx_nga, az_jb, 
     :  d_jb, h_min_c, elev_sta, E_sta, N_sta, depth, d_sta_e,
     :  d_sta_n
     
      integer icase_jb, nflts, i, icase_c, icase_cd2f 
      
      logical cartesian_coordinates

      real N_ref(*), E_ref(*), elev_ref(*), h_ref(*), 
     :     strike_f(*), dip_f(*),
     :     w1(*), w2(*), s1(*), s2(*),
     :     d_jb_segs(*), d_cd2f_segs(*), d_c_segs(*),
     :     az_jb_segs(*), rx_nga_segs(*), ry0_nga_segs(*)
     
      integer icase_jb_segs(*)


      d_jb = 10000.0
      d_cd2f = 10000.0
      d_c = 10000.0
      rx_nga = 10000.0
      ry0_nga = 10000.0
      
      do i = 1, nflts

        depth = (elev_sta - elev_ref(i))/1000.0 + h_ref(i)  ! "1000" to convert
                                                            ! from m to km

        call dist_3df(cartesian_coordinates, N_sta, E_sta, 
     :   N_ref(i), E_ref(i), depth, strike_f(i), dip_f(i), 
     :   w1(i), w2(i), s1(i), s2(i), 
     :   h_min_c, 
     :   d_jb_segs(i), az_jb_segs(i), rx_nga_segs(i), ry0_nga_segs(i),
     :   d_cd2f_segs(i), az_cd2f, 
     :   d_c_segs(i), az_c, 
     :   d_sta_n, d_sta_e, icase_cd2f, icase_c, icase_jb_segs(i))

!        write(*,'(a,1x,i2,1p3(1x,e10.3))')
!     :   '  iflt, d_jb_segs, d_cd2f_segs, d_c_segs = ',
!     :         i, d_jb_segs(i), d_cd2f_segs(i), d_c_segs(i)

        if (d_jb_segs(i) .lt. d_jb) d_jb = d_jb_segs(i)
        if (d_cd2f_segs(i) .lt. d_cd2f) d_cd2f = d_cd2f_segs(i)
        if (d_c_segs(i) .lt. d_c) d_c = d_c_segs(i)
        if (rx_nga_segs(i) .lt. rx_nga) rx_nga = rx_nga_segs(i)
        if (ry0_nga_segs(i) .ge. 0.0 .and. ry0_nga_segs(i) .lt. ry0_nga) 
     :                             ry0_nga = ry0_nga_segs(i)

      end do
      
      az_jb = az_jb_segs(nflts)
      icase_jb = icase_jb_segs(nflts)
      rx_nga = rx_nga_segs(nflts)
      ry0_nga = ry0_nga_segs(nflts)
      

!        write(*,'(a,1p3(1x,e10.3))')
!     :   '  d_jb, d_cd2f, d_c = ',
!     :      d_jb, d_cd2f, d_c

      return
      end
! ----------------------------------------------------------------- DIST3DMF

      include '\forprogs\dist_3df.for'

