      subroutine Read_CSV(cstr, kparm, type, c, nc, f, ru, i, 
     :                    iu, istat)
      
* Read Comma Separated Variable (csv) file

* input: cstr = input comma-delimited string
* input: kparm = number of parameter to extract
* input: type = type of parameter (character = "C", real = "F", integer = "I")
* output: c = value of character parameter
* output: nc = number of characters in c
* output: f = value of real parameter
* input: ru: f = ru if the real parameter is undefined (consecutive commas)
* output: i = value of integer parameter
* input: iu: i = iu if the integer parameter is undefined (consecutive commas)
* output: istat: status of operation (
*         ISTAT= 0 -> OK
*              = 1 -> KPARMth field is empty; return with F=RU or I=IU
*              = 2 -> KPARMth field is unreadable; return with F=RU.or I=IU

* Make sure deal properly with blanks in c, f, or i fields

* Dates: 11/24/04 - Written by D. Boore, by combining C. Mueller's csr 
*                   programs together
*        08/02/05 - Check for reference to cstr index 0 in csvr123.  Also, 
*                   I should thoroughly go over the logic of csvr123, 
*                   because it does not seem quite right to me.
*        12/07/05 - Disable search for '=' as start of string

      character cstr*(*), c*(*), type*1
      
      c = ' '
      nc = 0
      f = ru
      i = iu
      if (type .eq. 'C' .or. type .eq. 'c') then
        call CSRC (KPARM,CSTR,C,NC)
      else if (type .eq. 'F' .or. type .eq. 'f') then
        call CSRF (KPARM,CSTR,F,ISTAT,RU)
      else if (type .eq. 'I' .or. type .eq. 'i') then
        call CSRI (KPARM,CSTR,I,ISTAT,IU)
      else
        istat = -1 ! error, not a valid type
      end if 
      
      return
      end
      
      
      subroutine CSVR123 (CSTR,K1,K2,K3)

c Parse next field in character string CSTR for CSRC, CSRI, and CSRF.
c Fields are separated by one comma.
c Starting at last separator (K3 @call), find
c  start of field (K1), end of field (K2), and next separator (K3 @return).
c If field is empty return with K1=K3.
c Separators between quotes (") are ignored; separator must follow 2nd quote.
c Written by C. Mueller, USGS.

* Dates: 11/24/04 - Modified C. Mueller's CSR123 routine to ignore
* blanks, using commas as delimiters.

      character CSTR*(*),C1*1

      LCSTR = Len(CSTR)
      
      K = K3
      K = K+1
      if (K.gt.LCSTR.or.CSTR(K:K).eq.',') goto 3
      K1 = K
      if (CSTR(K:K).eq.'"') then
        if (K.eq.LCSTR) goto 3
        K1 = K+1
        K = K1+Index(CSTR(K1+1:LCSTR),'"')
        if (K.eq.K1) K = LCSTR+1
      endif
      KCOMMA = K+Index(CSTR(K+1:LCSTR),',')
      if (KCOMMA.eq.K) KCOMMA = LCSTR+1
      K3 = KCOMMA - 1
      K2 = K3
 
      if (K1-1 .gt. 0) then 
        if (CSTR(K1-1:K1-1).eq.'"') K2 = K-1
      end if
      
      K3 = K3+1
      if (K3.gt.LCSTR.or.CSTR(K3:K3).eq.',') return
      K3 = K3-1
      return
3     K3 = K
      K1 = K3
      return

      end
      
      subroutine CSRC (KPARM,CSTR,C,NC)
      
c Read character string C(1:NC) from the KPARMth field in CSTR.
c (Fields start after an optional '='; see subroutine CSR123 for field rules.)
! NOW DISABLED
c If the KPARMth field is empty or nonexistent return with C empty and NC=0.
c Written by C. Mueller, USGS.
      
      character CSTR*(*),C*(*)
      
c find start and end of KPARMth field and get C(1:NC)
!      K3 = Index(CSTR,'=')
      K3 = 0
      do K=1,KPARM
        call CSVR123 (CSTR,K1,K2,K3)
      end do
      if (K1.eq.K3) goto 101
      C = CSTR(K1:K2)
      NC = Min(K2-K1+1,Len(C))
      return
c error
101   C = ' '
      NC = 0
      return
      
      end

      subroutine CSRF (KPARM,CSTR,F,ISTAT,RU)

c Read real F from the KPARMth field in CSTR.
c (Fields start after an optional '='; see subroutine CSR123 for field rules.)
! NOW DISABLED
c ISTAT= 0 -> OK
c      = 1 -> KPARMth field is empty; return with F=RU.
c      = 2 -> KPARMth field is unreadable; return with F=RU.
c Written by C. Mueller, USGS.

      character CSTR*(*)

c find start and end of KPARMth field and get F
!      K3 = Index(CSTR,'=')
      K3 = 0
      do K=1,KPARM
        call CSVR123 (CSTR,K1,K2,K3)
      end do
      if (K1.eq.K3) goto 101
      read (CSTR(K1:K2),'(f15.0)',err=102) F
      ISTAT = 0
      return
c error
101   ISTAT = 1
      F = RU
      return
102   ISTAT = 2
      F = RU
      return

      end

      subroutine CSRI (KPARM,CSTR,I,ISTAT,IU)

c Read integer I from the KPARMth field in CSTR.
c (Fields start after an optional '='; see subroutine CSR123 for field rules.)
! NOW DISABLED
c ISTAT= 0 -> OK
c      = 1 -> KPARMth field is empty; return with I=IU.
c      = 2 -> KPARMth field is unreadable; return with I=IU.
c Written by C. Mueller, USGS.

      character CSTR*(*)

c find start and end of KPARMth field and get I
!      K3 = Index(CSTR,'=')
      K3 = 0
      do 1 K=1,KPARM
        call CSVR123 (CSTR,K1,K2,K3)
1     continue
      if (K1.eq.K3) goto 101
      read (CSTR(K1:K2),'(i12)',err=102) I
      ISTAT = 0
      return
c error
101   ISTAT = 1
      I = IU
      return
102   ISTAT = 2
      I = IU
      return

      end
