
! --------------------------------------------- begin rotate_separate_in_out_variables
      subroutine Rotate_Separate_In_Out_Variables( z1_in, z2_in, znull,
     :               azm1_in, azm2_in, azmr, nz, 
     :               z1_out, z2_out, azm1_out, azm2_out)

! Rotates z1_in, z2_in into azmr (stored in z1_out on return) and
! azmr+90.0 (stored in z2_out on return).  No assumptions are made 
! about the relation between azm1 and azm2.  Znull is a number that
! represents no data or clipped data; if encountered, both z1_out and z2_out
! are replaced by znull.

! NOTE:  All azimuths can be absolute (clockwise from north), or azmr
!        can be relative to the azimuth for component 1, in which
!        case azm1_in should be set to 0.0 and azm2_in to +90.

! Conventions: all angles are clockwise from north and are measured
! in degrees.

! See NB#10, p. 22 for development of equations.

! Written by:  Dave Boore
! Dates: 07/07/88 - written
!        07/04/05 - replace isiz in real declaration with "*",
!                   and remove isize from calling list.
!        09/22/12 - Small changes in coding (e.g., remove statement number,
!                   replace .ge. with >=, etc).
!        02/07/18 - A revised version of Rotate.For, using separate input and
!                   output variables to avoid overwriting the input variables,
!                   which has been a problem with Rotate.For

      real z1_in(*), z2_in(*)
      real z1_out(*), z2_out(*)

      pi = 4.0*atan(1.0)
      dtor = pi/180.0

      cr1 = cos( (azmr-azm1_in)*dtor )
      sr1 = sin( (azmr-azm1_in)*dtor )
      cr2 = cos( (azmr-azm2_in)*dtor )
      sr2 = sin( (azmr-azm2_in)*dtor )

      loop over points: DO i = 1, nz

         if (z1_in(i) == znull .or. z2_in(i) == znull) then

            z1_out(i) = znull
            z2_out(i) = znull
            cycle loop over points

         endif

         cp1 = z1_in(i)
         cp2 = z2_in(i)

         z1_out(i) =  cr1*cp1 + cr2*cp2
         z2_out(i) = -sr1*cp1 - sr2*cp2
         
      END DO loop over points

      azm1_out = azmr
      azm2_out = azmr + 90.0
      if (azm2_out >= 360.0) azm2_out = azm2_out-360.0

      return
      end
! --------------------------------------------- end rotate_separate_in_out_variables
 