*------------------   Begin rs2read   ----------------------------------
      subroutine rs2read(f_rs2, 
     :        damp, ndamp, per, nper, rd, rv, psv, aa, 
     :        char_head, int_head, real_head, comments,
     :        itflag, tprd, tprv, tpaa)


* Read response spectra stored in rs2 format

* The output arrays char_head, int_head, real_head should be dimensioned
* as follows in the calling program:

*      character char_head(11)*80, comments(500)*80
*      integer int_head(48)
*      real real_head(50)
*      real rd(100,5), rv(100,5), psv(100,5), aa(100,5)
*      real tprd(100,5), tprv(100,5), tpaa(100,5)
*      real damp(5), per(xx), xx = 91 usually

*  Dates: 02/06/01 - Written by D. Boore, based on SMCRead
*         03/23/01 - Renamed it from smcrdrs2.for
*         05/25/01 - Include times of peak response
*         12/09/02 - Increased dimension of arrays (note: must specify
*                    300 in calling array; cannot make it a variable?)

      real real_head(*)
      integer int_head(*)
      character*80 char_head(*), comments(*)
      character f_rs2*(*)
      real rd(300,5), rv(300,5), psv(300,5), aa(300,5)
      real tprd(300,5), tprv(300,5), tpaa(300,5)
      real damp(*), per(*)
      
      call get_lun(nu_rs2)
*      call trim_c(f_rs2,nc_f_rs2)
      open(unit= nu_rs2, file=f_rs2, status='unknown')

      do i = 1, 11
        read(nu_rs2, '(a)') char_head(i)
      end do

      read(nu_rs2, '(8I10)') (int_head(i), i=1, 48)

      read(nu_rs2, '(5e15.7)') (real_head(i), i = 1, 50)

      do i = 1, int_head(16)
        read(nu_rs2,'(a)') comments(i)
      end do

      read(nu_rs2, *)   ! skip line with unit information

      read(nu_rs2, *) ndamp, nper, itflag

      read(nu_rs2, *) (damp(i), i = 1, ndamp)
      read(nu_rs2, *) (per(i), i = 1, nper)

      do ii = 1, ndamp
        read(nu_rs2,*)
        read(nu_rs2,*) (rd(i,ii),i=1, nper)

        read(nu_rs2,*)
        read(nu_rs2,*) (rv(i,ii),i=1, nper)

        read(nu_rs2,*)
        read(nu_rs2,*) (psv(i,ii),i=1, nper)

        read(nu_rs2,*)
        read(nu_rs2,*) (aa(i,ii),i=1, nper)

        if (itflag .eq. 1) then
          read(nu_rs2,*)
          read(nu_rs2,*) (tprd(i,ii),i=1, nper)

          read(nu_rs2,*)
          read(nu_rs2,*) (tprv(i,ii),i=1, nper)

          read(nu_rs2,*)
          read(nu_rs2,*) (tpaa(i,ii),i=1, nper)

        else
          do i = 1, nper          
            tprd(i,ii) = 0.0
            tprv(i,ii) = 0.0
            tpaa(i,ii) = 0.0
          end do
        end if

      end do
      
      close(unit=nu_rs2)

      return
      end
*------------------   End rs2read   ----------------------------------

